const moduleAlias = require('module-alias');
moduleAlias.addAlias('@', () => __dirname);


const Koa = require('koa');
const favicon = require('koa-favicon');
const helmet = require('koa-helmet');

require("./db");

const auth = require("./middleware/auth");
const onerror = require('./middleware/onerror');
const header = require('./middleware/header');
const ratelimit = require('./middleware/ratelimit');

const router = require('./router');
const mount = require('koa-mount');

const apiResponseHandler = require('./middleware/api-response-handler');

const app = new Koa();
app.proxy = true;

app.use(favicon(__dirname + '/favicon.png'));
if (process.env.DOC) {
    app.use(serve("./doc/out"));
}

app.use(serve(config.file.upload_dir));

app.use(helmet());
app.use(onerror);
app.use(header);
app.use(apiResponseHandler());

app.use(koaBody({
    formLimit: config.file.max_form_limit,
    multipart: true,
    formidable: {
        maxFileSize: config.file.max_file_limit,
        keepExtensions: true
    }
}));

// router
app.use(auth);
app.use(ratelimit);
app.use(mount('/', router.routes())).use(router.allowedMethods());

module.exports = app;