const logger = require('@/utils/logger');
const config = require('@/config').value;
const { RequestProgressError } = require('@/errors');

let Sentry;

if (config.sentry.dsn) {
    Sentry = Sentry || require('@sentry/node');
    Sentry.init({
        dsn: config.sentry.dsn,
    });
    Sentry.configureScope((scope) => {
        scope.setTag('node_name', config.nodeName);
    });

    logger.info('Sentry inited.');
}

module.exports = async (ctx, next) => {
    try {
        await next();

    } catch (err) {
        let message = err;
        if (err.name && (err.name === 'HTTPError' || err.name === 'RequestError')) {
            message = err.message;

        } else if (err instanceof Error) {
            message = process.env.NODE_ENV === 'prod' ? "System error..." : err.stack;
        }

        if (process.env.NODE_ENV !== 'prod') {
            logger.error(`Error in ${ctx.request.path}: ${err.stack}`);
        }

        if (process.env.NODE_ENV === 'prod' && !(err instanceof RequestProgressError)) {
            logger.error(`Error in ${ctx.request.path}: ${err.stack}`);
        }

        if (ctx.body) {
            ctx.body.message = ctx.body.message || message;

        } else {
            ctx.body = {
                code: -1,
                message
            };
        }
    }
};
