const ratelimit = require('koa-ratelimit');
const config = require('@/config').value;
const logger = require('@/utils/logger');
const { clients, getValue } = require('@/tools/redis');

const BLACKLIST_IP_PREFIX = "blacklist:ip:";

const error_message = {
    code: -1,
    message: 'too many requests'
};

module.exports = ratelimit({
    driver: 'redis',
    db: clients.redis,
    max: config.ratelimit.max,
    duration: config.ratelimit.duration || 60 * 1000,
    errorMessage: error_message,
    id: (ctx) => ctx.ip.split(":").pop(),
    headers: {
        remaining: 'Rate-Limit-Remaining',
        reset: 'Rate-Limit-Reset',
        total: 'Rate-Limit-Total'
    },
    disableHeader: false,
    whitelist: () => process.env.NODE_ENV === 'dev',
    blacklist: async (ctx) => {
        const ip = ctx.ip.split(":").pop();
        if (await getValue(BLACKLIST_IP_PREFIX + ip)) {
            logger.info(`${ip} is in blacklist`);
            return true;
        }
    }
});
