const fs = require('fs');
const path = require('path');

const { moment, logger } = require('./index');
const config = require("@/config").value;
const uuid = require('uuid');

const mkdirFile = (path_dir) => {
    let file_dir = '';
    const pathList = path_dir.split('/');
    pathList.forEach((i) => {
        if (i) {
            file_dir = path.join(file_dir, i);
            if (!fs.existsSync(file_dir)) {
                fs.mkdirSync(file_dir);
            }
        }
    });
};

const saveFile = (file, path) => new Promise((resolve, reject) => {
    const render = fs.createReadStream(file);
    const upStream = fs.createWriteStream(path);
    render.pipe(upStream);
    upStream.on('finish', () => {
        resolve(path);
    });

    upStream.on('error', (err) => {
        reject(err);
    });
});

const upload = async (ctx, db) => {
    const file = ctx.request.files.file;
    const file_upload_name = file.name || file.originalFilename;
    const tail = file_upload_name === 'blob' ? 'png' : file_upload_name.split('.').pop();
    const m = moment();

    const file_s_dir = path.join(m.year() + '', (m.month() + 1) + '', m.date() + '');
    const file_name = path.join(file_s_dir, uuid.v4() + '.' + tail);
    const file_path = path.join(config.file.upload_dir, file_s_dir);

    mkdirFile(file_path);
    try {
        await saveFile(file.path, path.join(config.file.upload_dir, file_name));
        await db.FileResources.create({
            name: file_upload_name,
            type: file.type,
            url: file_name,
            size: file.size,
            used: false
        });

        ctx.res.ok({ data: { url: file_name } });

    } catch (e) {
        logger.error(`upload file :%s`, e);
        ctx.res.fail({ message: 'file upload error...' });
    };
};

const destroyFile = (url) => {
    if (!url) { return; }
    fs.unlinkSync(url);
};

const getFile = (url) => fs.readFileSync(path.join(config.file.upload_dir, url));

const useFile = async (url, db) => {
    if (!url) { return; }
    url = url.replaceAll(config.serverUrl, '');
    const fr = await db.FileResources.findOne({ where: { url } });
    if (fr) {
        fr.used = true;
        await fr.save();
    }
};

module.exports = {
    upload,
    getFile,
    useFile,
    destroyFile
};