#!/usr/bin/env node
const program = require('commander')
var fs = require("fs")
const cwd = process.cwd();
const packageJson = require('../package.json');
const version = packageJson.version;
const Metalsmith = require('metalsmith')
const inquirer = require('inquirer')
const Handlebars = require('handlebars')

program
    .version(`${version}`, '-v, --version')
    .command('create')
    .description('create a new project')
    .action(() => {
        initProject();
    })

async function initProject() {

    let metadata = await inquirer.prompt([
        {
            name: 'project_name',
            message: 'project name',
            default: `test-project`
        }, {
            name: 'project_version',
            message: 'project version',
            default: '1.0.0'
        }, {
            name: 'project_desc',
            message: 'project desc',
            default: `A project named test-project`
        }
    ])

    let src_dir = `${__dirname}/generator`
    let target_ir = `${cwd}/${metadata.project_name}`

    if (fs.existsSync(target_ir)) {
        console.error(`${target_ir} exist !!!`);
    }

    await Metalsmith(process.cwd())
        .metadata(metadata)
        .clean(false)
        .source(src_dir)
        .destination(target_ir)
        .use((files, metalsmith) => {
            const meta = metalsmith.metadata()
            Object.keys(files).forEach(fileName => {
                let fs_pref = fileName.split('.');
                if (fs_pref.length > 1 && ['js', 'css', 'ts', 'json'].includes(fs_pref[fs_pref.length - 1])) {
                    const t = files[fileName].contents.toString()
                    files[fileName].contents = Buffer.from(Handlebars.compile(t)(meta))
                }
            })
        })
        .build(err => {
            if (err) {
                console.warn('', err);
            } else {
                console.log(`project create success!!\ncd ${metadata.project_name}\nnpm install \nnpm run dev`)
            }
        })
}

program.parse()